from django.test.runner import DiscoverRunner
from django.conf import settings
import unittest

class SkipCase(unittest.TestCase):
    
    def runTest(self):
        raise unittest.SkipTest("Skipping test based on the settings")


class SkipTestRunner(DiscoverRunner):

    def build_suite(self, test_labels=None, extra_tests=None, **kwargs):

        skip_tests = settings.SKIP_TEST_CLASSES
        if len(skip_tests) > 0:
            new_suite = unittest.TestSuite()
            suite = super().build_suite(test_labels, extra_tests, **kwargs)
            for test in suite._tests:
                test_class_name = test.__class__.__name__
                if test_class_name.startswith("Test") and test_class_name in skip_tests:
                    test_name = test._testMethodName
                    setattr(test, test_name, getattr(SkipCase(), 'runTest'))
                else:
                    new_suite.addTest(test)
            return new_suite
        else:
            return super().build_suite(test_labels, extra_tests, **kwargs)


from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '1.0.0'
DESCRIPTION = 'Django Library To Skip Tests'
LONG_DESCRIPTION = 'A Simple django library to skip some tests from a Django project.'

# Setting up
setup(
    name="django-skiptest",
    version=VERSION,
    author="Naveen Singh (Noida, India)",
    author_email="naveen.singh@outlook.in",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'django', 'skip tests', 'ignore tests', 'django ignore tests', 'django skip tests'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)